### Name: bmonomvn
### Title: Bayesian Estimation for Multivariate Normal Data with Monotone
###   Missingness
### Aliases: bmonomvn
### Keywords: multivariate regression

### ** Examples

## standard usage, duplicating the results in
## Little and Rubin, section 7.4.3
data(cement.miss)
out <- bmonomvn(cement.miss)
out
out$mu
out$S

##
## A bigger example, comparing the various methods
##

## generate N=100 samples from a 10-d random MVN
xmuS <- randmvn(100, 20)

## randomly impose monotone missingness
xmiss <- rmono(xmuS$x)

## using least squares only when necessary
obl <- bmonomvn(xmiss)
obl
rmse.muS(obl$mu, obl$S, xmuS$mu, xmuS$S)
oml <- monomvn(xmiss, method="lasso")
rmse.muS(oml$mu, oml$S, xmuS$mu, xmuS$S)

## using least squares sparingly
obls <- bmonomvn(xmiss, p=0.25)
rmse.muS(obls$mu, obls$S, xmuS$mu, xmuS$S)
omls <- monomvn(xmiss, p=0.25, method="lasso")
rmse.muS(omls$mu, omls$S, xmuS$mu, xmuS$S)

#### compare to ridge regression
obrs <- bmonomvn(xmiss, p=0.25, method="ridge")
rmse.muS(obrs$mu, obrs$S, xmuS$mu, xmuS$S)
omrs <- monomvn(xmiss, p=0.25, method="ridge")
rmse.muS(omrs$mu, omrs$S, xmuS$mu, xmuS$S)

## using the maximum likelihood solution to initialize
## the Markov chain and avoid burn-in.  
ob2s <- bmonomvn(xmiss, p=0.25, B=0, start=omls, RJ="p")
rmse.muS(ob2s$mu, ob2s$S, xmuS$mu, xmuS$S)



